<html>
<head>
<link rel="stylesheet" type="text/css" href="styles/Style.css">
<script language="JavaScript" type="text/javascript" src="ajax.js"></script>
</head>
<body>
<?php
require_once("class/class.conectar.php");
require_once("class/class.usutrab.php");
require_once("class/class.horaprog.php");
require_once("class/class.horareprog.php");
require_once("class/class.horaeje.php");
require_once("class/class.descmed.php");
require_once("class/class.licencia.php");
require_once("class/class.descrad.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

date_default_timezone_set("America/Lima"); setlocale(LC_TIME,"es_PE.UTF-8");

if(isset($_GET['dia']) && $_GET['dia']!="" ) 
{ 
// si existe lo deserializamos para poder tratarlo 
$arrcodprog = unserialize(stripslashes($_GET['dia'])); 
$horaext = unserialize(stripslashes($_GET['extra'])); 

$idj=$_GET['idj'];
$idsa=$_GET['ids'];
$idga=$_GET['idga'];
$ida=$_GET['ida'];
$idh=$_GET['idh'];
$anno=$_GET['anno'];
$mm=$_GET['mes'];
$idtp=$_GET['idtp'];
$usuprog=$_GET['ugid'];
$val=$_GET['valor'];


for ($j=1;$j<=count($arrcodprog);$j++){
$codprog = $arrcodprog[$j-1];
$thora = $horaext[$j-1];
$entrada=0;
$cero=0;

$unicocod =$arrcodprog[$j-1].$cero;

if($unicocod!="0"){
 //pregunta si esta programada para trabajar drante el mes
 $Objut = new UsuarioTrabaja();
 $res_p = array();
 $res_p = $Objut->buscar_per_trab_usudep($conex,$anno,$mm,$idj,$idsa,$idtp,$codprog);

if(count($res_p)>0){
$codper=$res_p[0]['ug_id'];
$ids=$res_p[0]['s_id'];

//consullta si esta programada en el dia 
if($val==1){
$Objp = new Horaprogramacion();
$res_hp = array();
$res_hp=$Objp->consulta_hrprog_dia_tipohr($conex,$anno,$mm,$idj,$ids,$idsa,$idtp,$idh,$j,$idga,$ida,$codper,$thora);
}
if($val==2){
$Objp = new HoraReprogramacion();
$res_hp = array();
//consulta si tiene turno
$res_hp=$Objp->consulta_hrreprog_dia_tipohr($conex,$anno,$mm,$idj,$ids,$idsa,$idtp,$idh,$j,$idga,$ida,$codper,$thora);
}
//OK

if(count($res_hp)==0){
if($val==1){
	//elimina al quien esta y registra
$Objp->elimina_hrprog_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida); 
$Objp->registra_hrprog_dia($conex,$anno,$mm,$idj,$ids,$idsa,$idtp,$idh,$j,$idga,$ida,$codprog,$codper,$thora,$usuprog);
}
if($val==2){

$Objp->elimina_hrreprog_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida);
$Obje = new HoraEjecucion();  
$Obje->elimina_hreje_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida);
//validar dm, lic, desrad
$Objdm = new DescansoMedico();
$Objdr = new DescansoRadiacion();
$Objlic = new Licencia();
$res_dm = array(); $res_lic = array(); $res_dr= array();
$fecha = $anno."-".$mm."-".$j;
$res_dm = $Objdm->consultar_descmed_fecha($conex,$codper,$fecha);
$res_lic = $Objlic->consultar_licencia_anterior($conex,$codper,$fecha);
$res_dr = $Objdr->consultar_descrad($conex,$codper,$fecha);
//print_r($res_dm);
//print_r($res_lic);
//print_r($res_dm);
if(count($res_dm)==0 && count($res_lic)==0 && count($res_dr)==0){
$Objp->registra_hrreprog_dia($conex,$anno,$mm,$idj,$ids,$idsa,$idtp,$idh,$j,$idga,$ida,$codprog,$codper,$thora,$usuprog);
}
}
}}

}else{
if($val==1){
$ObjProg = new HoraProgramacion();
$ObjProg->elimina_hrprog_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida);
}
if($val==2){
$ObjReprog = new HoraReprogramacion();
$ObjReprog->elimina_hrreprog_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida);
$ObjEje = new HoraEjecucion();
$ObjEje->elimina_hreje_dia($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida);
$ObjReprog->elimina_hrsrepro_dia_sincod($conex,$anno,$mm,$idj,$idsa,$idtp,$idh,$j,$idga,$ida,2);

}}//end else
}//end for
}//end if GET

  $fal = rand();
if($val==1){
$url = "progasistencial.php?idj=".$idj."&ids=".$idsa."&anno=".$anno."&mes=".$mm."&idtp=".$idtp."&ugid=".$usuprog."&tt=".$fal;
}

if($val==2){
$url = "reprogramacionmes.php?idj=".$idj."&ids=".$idsa."&anno=".$anno."&mes=".$mm."&idtp=".$idtp."&ugid=".$usuprog."&tt=".$fal;
}

//echo "<script language=Javascript> location.href=\"$url\"; </script>";
echo "<script language=Javascript> location.href=\"$url\"; </script>";
//header("Location:".$url);
?>
</body>
</html>
